RawMasterFile
===============


.. doxygenclass:: aare::RawMasterFile
   :members:
   :undoc-members:
   :private-members:


.. doxygenclass:: aare::RawFileNameComponents
   :members:
   :undoc-members:
   :private-members: